# Clustered-Federated-Learning
A shared library for performing experiments on Clustered Federated Learning, published as a part of the paper by M.K.Zuziak, R.Pellungrini and S.Rinzivillo: One-Shot Clustering for Federated Learning
